==> haskell-io-streams-haproxy-1.0.1.0-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.1.0
id: io-streams-haproxy-1.0.1.0-JyudmQujGEjC0ZWRKBJc4T
key: io-streams-haproxy-1.0.1.0-JyudmQujGEjC0ZWRKBJc4T
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: 902cc34be3d5a1f85525e5ecb1bc6d23
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-haproxy-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/io-streams-haproxy-1.0.1.0
hs-libraries: HSio-streams-haproxy-1.0.1.0-JyudmQujGEjC0ZWRKBJc4T
depends:
    attoparsec-0.13.2.2-IaNz9bz10S32KGLwZomjal base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.1.0-C3w34be0mWaK7VzwX1GUCu
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.1.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.1.0
id: io-streams-haproxy-1.0.1.0-Kjwb1VsZk1PHMbK5g6H2NW
key: io-streams-haproxy-1.0.1.0-Kjwb1VsZk1PHMbK5g6H2NW
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: a320d5b17f053d47572bc7f4347df4e0
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-haproxy-1.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/io-streams-haproxy-1.0.1.0
hs-libraries: HSio-streams-haproxy-1.0.1.0-Kjwb1VsZk1PHMbK5g6H2NW
depends:
    attoparsec-0.13.2.2-L0PhfJn0b3D3Qcx7KDBMXo base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.1.0-CNDSraTFmNHCUP37odCGw0
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
